@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.ejection import Ejection
+from pbpstats.resources.enhanced_pbp import Ejection
 
 
 class DataEjection(Ejection, DataEnhancedPbpItem):
