@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.end_of_period import EndOfPeriod
+from pbpstats.resources.enhanced_pbp import EndOfPeriod
 
 
 class DataEndOfPeriod(EndOfPeriod, DataEnhancedPbpItem):
