@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.foul import Foul
+from pbpstats.resources.enhanced_pbp import Foul
 
 
 class DataFoul(Foul, DataEnhancedPbpItem):
