@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.free_throw import FreeThrow
+from pbpstats.resources.enhanced_pbp import FreeThrow
 
 
 class DataFreeThrow(FreeThrow, DataEnhancedPbpItem):
