@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.jump_ball import JumpBall
+from pbpstats.resources.enhanced_pbp import JumpBall
 
 
 class DataJumpBall(JumpBall, DataEnhancedPbpItem):
