@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.rebound import Rebound
+from pbpstats.resources.enhanced_pbp import Rebound
 
 
 class DataRebound(Rebound, DataEnhancedPbpItem):
