@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.replay import Replay
+from pbpstats.resources.enhanced_pbp import Replay
 
 
 class DataReplay(Replay, DataEnhancedPbpItem):
