@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.start_of_period import StartOfPeriod
+from pbpstats.resources.enhanced_pbp import StartOfPeriod
 
 
 class DataStartOfPeriod(StartOfPeriod, DataEnhancedPbpItem):
