@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.data_nba.enhanced_pbp_item import DataEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.violation import Violation
+from pbpstats.resources.enhanced_pbp import Violation
 
 
 class DataViolation(Violation, DataEnhancedPbpItem):
