@@ -1,8 +1,5 @@
 from pbpstats.resources.base import Base
-from pbpstats.resources.enhanced_pbp.field_goal import FieldGoal
-from pbpstats.resources.enhanced_pbp.free_throw import FreeThrow
-from pbpstats.resources.enhanced_pbp.rebound import Rebound
-from pbpstats.resources.enhanced_pbp.turnover import Turnover
+from pbpstats.resources.enhanced_pbp import FieldGoal, FreeThrow, Rebound, Turnover
 
 
 class EnhancedPbp(Base):
