@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.stats_nba.enhanced_pbp_item import StatsEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.ejection import Ejection
+from pbpstats.resources.enhanced_pbp import Ejection
 
 
 class StatsEjection(Ejection, StatsEnhancedPbpItem):
