@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.stats_nba.enhanced_pbp_item import StatsEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.end_of_period import EndOfPeriod
+from pbpstats.resources.enhanced_pbp import EndOfPeriod
 
 
 class StatsEndOfPeriod(EndOfPeriod, StatsEnhancedPbpItem):
