@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.stats_nba.enhanced_pbp_item import StatsEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.free_throw import FreeThrow
+from pbpstats.resources.enhanced_pbp import FreeThrow
 
 
 class StatsFreeThrow(FreeThrow, StatsEnhancedPbpItem):
