@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.stats_nba.enhanced_pbp_item import StatsEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.timeout import Timeout
+from pbpstats.resources.enhanced_pbp import Timeout
 
 
 class StatsTimeout(Timeout, StatsEnhancedPbpItem):
