@@ -1,5 +1,5 @@
 from pbpstats.resources.enhanced_pbp.stats_nba.enhanced_pbp_item import StatsEnhancedPbpItem
-from pbpstats.resources.enhanced_pbp.turnover import Turnover
+from pbpstats.resources.enhanced_pbp import Turnover
 
 
 class StatsTurnover(Turnover, StatsEnhancedPbpItem):
